@@ -42,12 +42,12 @@ except ImportError:
 from hghooks import CheckerManager, re_options
 
 
-def pep8_checker(ignore=''):
+def pep8_checker(pep8_options):
     extra_args = []
-    if ignore:
-        ignore_spec = ','.join([ign.strip(', ') for ign in ignore.split()
-                                if ign.strip(', ')])
-        extra_args.append('--ignore=%s' % ignore_spec)
+    for key, value in pep8_options.iteritems():
+        value_spec = ','.join([ign.strip(', ') for ign in value.split()
+                              if ign.strip(', ')])
+        extra_args.append('--%s=%s' % (key, value_spec))
 
     def check_pep8(files_to_check, msg):
         for filename, data in files_to_check.items():
@@ -70,13 +70,18 @@ def pep8_checker(ignore=''):
 
 
 def pep8hook(ui, repo, hooktype, node, pending, **kwargs):
-    if HAS_PEP8:
-        pep8_ignores = ui.config('pep8', 'ignore', '')
-        checker_manager = CheckerManager(ui, repo, node, 'no-pep8')
-        return checker_manager.check(pep8_checker(pep8_ignores))
-    else:
+    if not HAS_PEP8:
         ui.warn('You need the pep8 python module to use the pep8hook')
-        return 1
+        return True  # Failure
+
+    pep8_options = {}
+    options = ['exclude', 'filename', 'select', 'ignore', 'max-line-length']
+    for opt in options:
+        if ui.config('pep8', opt, ''):
+            pep8_options[opt] = ui.config('pep8', opt, '')
+            
+    checker_manager = CheckerManager(ui, repo, node, 'no-pep8')
+    return checker_manager.check(pep8_checker(pep8_options))
 
 
 pdb_catcher = re.compile(r'^[^#]*pdb\.set_trace\(\)', re_options)
@@ -162,12 +167,12 @@ def pyflakes_checker(files_to_check, msg):
 
 
 def pyflakeshook(ui, repo, hooktype, node, pending, **kwargs):
-    if HAS_PYFLAKES:
-        checker_manager = CheckerManager(ui, repo, node, 'no-pyflakes')
-        return checker_manager.check(pyflakes_checker)
-    else:
+    if not HAS_PYFLAKES:
         ui.warn('You need the pyflakes python module to use the pyflakeshook')
-        return 1
+        return True  # Failure
+
+    checker_manager = CheckerManager(ui, repo, node, 'no-pyflakes')
+    return checker_manager.check(pyflakes_checker)
 
 
 def jslint_check(data, filename):
@@ -185,10 +190,10 @@ def jslint_checker(files_to_check, msg):
 
 
 def jslinthook(ui, repo, hooktype, node, pending, **kwargs):
-    if HAS_JSLINT:
-        checker_manager = CheckerManager(ui, repo, node, 'no-jslint',
-                                         extension='.js')
-        return checker_manager.check(jslint_checker)
-    else:
+    if not HAS_JSLINT:
         ui.warn('You need the pyjslint python module to use the jslinthook')
-        return 1
+        return True  # Failure
+
+    checker_manager = CheckerManager(ui, repo, node, 'no-jslint',
+                                     extension='.js')
+    return checker_manager.check(jslint_checker)
